@@ -275,7 +275,7 @@ mp_tan(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
     mp_cos(x, unit, &cos_x);
     if (mp_is_zero(&cos_x)) {
         /* Translators: Error displayed when tangent value is undefined */
-        mperr(_("Tangent is undefined for angles that are multiples of π∕2 (180°) from π∕4 (90°)"));
+        mperr(_("Tangent is undefined for angles that are multiples of π (180°) from π∕2 (90°)"));
         mp_set_from_integer(0, z);
         return;
     }
